@@ -142,4 +142,9 @@ void apt_worker_get_system_update_packages (int state,
 void apt_worker_flash_and_reboot (apt_worker_callback *callback,
 				  void *data);
 
+void apt_worker_set_options (const char *options,
+			     apt_worker_callback *callback,
+			     void *data);
+
+
 #endif /* !APT_WORKER_CLIENT_H */
