@@ -470,6 +470,22 @@ package_info::get_display_name (bool installed)
   return n;
 }
 
+const char *
+package_info::get_display_version (bool installed)
+{
+  const char *v;
+  if (installed)
+    v = installed_version;
+  else
+    v = available_version;
+
+  const char *p = strchr (v, ':');
+  if (p)
+    v = p + 1;
+
+  return v;
+}
+
 void
 package_info::ref ()
 {
@@ -2642,8 +2658,7 @@ enable_search (bool f)
 static void
 enable_refresh (bool f)
 {
-  if (!red_pill_mode
-      && current_tb_struct->refresh_button)
+  if (current_tb_struct->refresh_button)
     gtk_widget_set_sensitive (current_tb_struct->refresh_button, f);
 }
 
