@@ -454,7 +454,7 @@ ip_install_with_info (void *data)
 			? _("ai_nc_update")
 			: _("ai_nc_install")),
 		       pi->get_display_name (false),
-		       pi->available_version, download_buf);
+		       pi->get_display_version (false), download_buf);
       
       ask_yes_no_with_arbitrary_details ((pi->installed_version
 					  ? _("ai_ti_confirm_update")
@@ -684,7 +684,7 @@ ip_install_loop (ip_clos *c)
 		{
 		  str = g_strdup_printf (_("ai_ni_update_successful"),
 					 pi->get_display_name (false),
-					 pi->available_version);
+					 pi->get_display_version (false));
 		}
 	      else
 		{
@@ -1199,7 +1199,7 @@ ip_download_cur (void *data)
     {
       title = g_strdup_printf (_("ai_nw_updating"),
 			       pi->get_display_name (false),
-			       pi->available_version);
+			       pi->get_display_version (false));
     }
   else
     {
@@ -1308,7 +1308,10 @@ ip_download_cur_reply (int cmd, apt_proto_decoder *dec, void *data)
   if (result_code == rescode_success)
     ip_install_cur (c);
   else if (entertainment_was_cancelled ())
-    ip_end (c);
+    {
+      apt_worker_clean (c->state, ip_clean_reply, NULL);
+      ip_end (c);
+    }
   else
     ip_download_cur_retry_confirm(result_code, c);
 }
@@ -1712,7 +1715,7 @@ uninstall_package (package_info *pi,
   size_string_general (size_buf, 20, c->pi->installed_size);
   g_string_printf (text, _("ai_nc_uninstall"),
 		   c->pi->get_display_name (true),
-		   c->pi->installed_version, size_buf);
+		   c->pi->get_display_version (true), size_buf);
 
   ask_yes_no_with_details (_("ai_ti_confirm_uninstall"), text->str,
 			   c->pi, remove_details,
@@ -2041,11 +2044,11 @@ if_details_reply (int cmd, apt_proto_decoder *dec, void *data)
   if (pi->installed_version)
     g_string_printf (text, _("ai_nc_update"),
 		     pi->get_display_name (false),
-		     pi->available_version, size_buf);
+		     pi->get_display_version (false), size_buf);
   else
     g_string_printf (text, _("ai_nc_install"),
 		     pi->get_display_name (false),
-		     pi->available_version, size_buf);
+		     pi->get_display_version (false), size_buf);
 
   void (*cont) (bool res, void *);
 
@@ -2086,7 +2089,7 @@ if_install (bool res, void *data)
 	{
 	  title = g_strdup_printf (_("ai_nw_updating"),
 				   c->pi->get_display_name (false),
-				   c->pi->available_version);
+				   c->pi->get_display_version (false));
 	}
       else
 	{
@@ -2134,7 +2137,7 @@ if_install_reply (int cmd, apt_proto_decoder *dec, void *data)
 	{
 	  str = g_strdup_printf (_("ai_ni_update_successful"),
 				 c->pi->get_display_name (false),
-				 c->pi->available_version);
+				 c->pi->get_display_version (false));
 	}
       else
 	{
