@@ -34,6 +34,7 @@
 #include <hildon/hildon-note.h>
 #include <hildon/hildon-caption.h>
 
+#include "menu.h"
 #include "repo.h"
 #include "settings.h"
 #include "apt-worker-client.h"
@@ -149,6 +150,8 @@ pill_response (GtkDialog *dialog, gint response, gpointer unused)
       red_pill_mode = (response == GTK_RESPONSE_YES);
       save_settings ();
 
+      set_settings_menu_visible (red_pill_mode);
+      update_backend_options ();
       if (red_pill_show_all || red_pill_show_magic_sys)
 	get_package_list (APTSTATE_DEFAULT);
     }
