@@ -1,7 +1,7 @@
 /*
  * This file is part of the hildon-application-manager.
  *
- * Copyright (C) 2005, 2006, 2007 Nokia Corporation.  All Rights reserved.
+ * Copyright (C) 2005, 2006, 2007, 2008 Nokia Corporation.  All Rights reserved.
  *
  * Contact: Marius Vollmer <marius.vollmer@nokia.com>
  *
@@ -34,7 +34,7 @@
 
   The Application Manager can run one interaction flow at any single
   time.  A local flow is started with START_INTERACTION_FLOW and ended
-  with END_INTERACTION_FLOW.  A flowe that should run on top of a
+  with END_INTERACTION_FLOW.  A flow that should run on top of a
   foreign window is started with START_FOREIGN_INTERACTION_FLOW and
   ended with END_INTERACTION_FLOW.
 
@@ -53,17 +53,41 @@
   END_INTERACTION_FLOW, as well as calls to PUSH_DIALOG and
   POP_DIALOG.
 
+  The function IS_IDLE can be used to check whether there is currently
+  a active interaction flow.  When it returns FALSE, a call to
+  start_interaction_flow would fail.
+
   See "Exiting" for how interaction flows influence the life
   time of the application.
+
+  
+  The function START_INTERACTION_FLOW_WHEN_IDLE will start an
+  interaction flow when the program has been idle for at least one
+  minute.  When that condition is true or when it becomes true in the
+  future, CONT will be called with DATA.  There can only be one
+  pending idle interaction flow.  START_INTERACTION_FLOW_WHEN_IDLE
+  returns false when one is already pending.
+
+  Calling RESET_IDLE_TIMER will inform the idle interaction flow
+  machinery that the user performed some action that should delay the
+  start of a pending interaction flow.  You don't need to do this for
+  interaction flows themselves, but for example when the user switches
+  the views.
 */
 
 bool start_interaction_flow ();
 bool start_foreign_interaction_flow (Window parent);
 void end_interaction_flow ();
+bool is_interaction_flow_active ();
+
+void reset_idle_timer ();
+bool start_interaction_flow_when_idle (void (*cont) (void *), void *data);
 
 void push_dialog (GtkWidget *dialog);
 void pop_dialog (GtkWidget *dialog);
 
+bool is_idle ();
+
 /** The main window
 
   PRESENT_MAIN_WINDOW and HIDE_MAIN_WINDOW will show and hide the main
@@ -104,6 +128,9 @@ void maybe_exit ();
   passed to the continuation CONT is true when the user clicks "Ok",
   of course, and false otherwise.
 
+  ASK_YES_NO_WITH_TITLE is like ask_yes_no but it constructs a real
+  dialog with title TITLE.
+
   ASK_CUSTOM is like ask_yes_no but allows the texts in the buttons to
   be specified.
 
@@ -113,6 +140,10 @@ void maybe_exit ();
   package info PI and hint INSTALLED.  See show_package_details for
   the meaning of PI and INSTALLED.
 
+  ASK_YES_NO_WITH_ARBITRARY_DETAILS is like ask_yes_no_with_details
+  but instead of showing a package details dialog, it invokes a
+  callback.
+
   ANNOY_USER display TEXT in a information note.  Clicking "Ok"
   removes that information note.  No continuation can be specified.
 
@@ -147,6 +178,11 @@ void maybe_exit ();
 void ask_yes_no (const gchar *question,
 		 void (*cont) (bool res, void *data), void *data);
 
+void ask_yes_no_with_title (const gchar *title,
+			    const gchar *question,
+			    void (*cont) (bool res, void *data),
+			    void *data);
+
 void ask_custom (const gchar *question,
 		 const gchar *ok_label, const gchar *cancel_label,
 		 void (*cont) (bool res, void *data), void *data);
@@ -154,6 +190,7 @@ void ask_custom (const gchar *question,
 void ask_yes_no_with_details (const gchar *title,
 			      const gchar *question,
 			      package_info *pi, detail_kind kind,
+			      const char *help_topic,
 			      void (*cont) (bool res, void *data), void *data);
 
 void ask_yes_no_with_arbitrary_details (const gchar *title,
@@ -190,21 +227,15 @@ void scare_user_with_legalese (bool sure,
 
 /* Progress dialog.
    
-   START_ENTERTAINING_USER shows a progress bar dialog with a cancel
-   button and STOP_ENTERTAINING_USER removes it.  These two functions
-   must be called in pairs and must be properly nested with respect to
+   START_ENTERTAINING_USER shows a progress bar dialog with or without
+   a cancel button (depending on the value for its only parameter) and
+   STOP_ENTERTAINING_USER removes it.  These two functions must be
+   called in pairs and must be properly nested with respect to
    push_dialog_parent and pop_dialog_parent.  There will only be at
    most one progress bar dialog active at any given time, and nesting
    start_entertaining_user/stop_entertaining_user will just maintain a
    counter of the nesting depth.
 
-   START_ENTERTAINING_USER_SILENTLY is like start_entertaining_user,
-   but does not actually show the progress dialog.  The effect of
-   using start_entertaining_user_silently is to keep a progress dialog
-   open until the corresponding stop_entertaining_user has been
-   called, but to wait for a nested call to start_entertaining_user
-   for actually showing the progress.
-
    SET_ENTERTAINMENT_FUN sets the state of the progress bar dialog.
    You can and should call this function before calling
    start_entertaining_user to setup the initial state of the dialog.
@@ -220,6 +251,14 @@ void scare_user_with_legalese (bool sure,
    button in the dialog.  When CALLBACK is NULL, the button is
    insensitive.
 
+   SET_ENTERTAINMENT_CANCEL associates a callback with the "Cancel"
+   button in the dialog.  When CALLBACK is NULL, the button is
+   insensitive.
+
+   SET_ENTERTAINMENT_SYSTEM_MODAL converts the progress bar dialog
+   into a system modal dialog. This operation is not reversible, so
+   the dialog will be system modal until it gets destroyed.
+
    CANCEL_ENTERTAINMENT calls the callback associated with
    set_entertainment_cancel, if there is one.
 
@@ -227,18 +266,41 @@ void scare_user_with_legalese (bool sure,
    has been called since the last call to start_entertaining_user.
    Clicking on the "Cancel" button will also call
    cancel_entertainment.
+
+   The entertainment can be divided into a sequence of 'games'.  Each
+   game is allocated its own segment of the progress bar.  For
+   example, you can specify that the first half of the progress bar
+   should be used for the first game, and the second half for the
+   second game.  Then, when setting the amount of fun with
+   set_entertainment_fun, the 100% percent mark for the first game is
+   in the middle of the progress bar.
+   
+   Games are played in sequence.  The next game starts when its ID is
+   first passed to set_entertainment_fun.  Games might be skipped.
  */
 
-void start_entertaining_user ();
-void start_entertaining_user_silently ();
+void start_entertaining_user (gboolean with_button);
 void stop_entertaining_user ();
 
-void set_entertainment_title (const char *main_title);
+void set_entertainment_main_title (const char *main_title,
+				   bool strong = false);
+void set_entertainment_sub_title (const char *sub_title);
+
+struct entertainment_game {
+  int id;
+  double fraction;
+};
+
+void set_entertainment_games (int n, entertainment_game *games);
+
 void set_entertainment_fun (const char *sub_title,
-			    int64_t alreday, int64_t total);
-void set_entertainment_download_fun (int64_t already, int64_t total);
+			    int game, int64_t alreday, int64_t total);
+void set_entertainment_download_fun (int game, int64_t already, int64_t total);
 
 void set_entertainment_cancel (void (*callback)(void *), void *data);
+
+void set_entertainment_system_modal (void);
+
 void cancel_entertainment ();
 bool entertainment_was_cancelled ();
 
@@ -395,6 +457,7 @@ void show_deb_file_chooser (void (*cont) (char *uri, void *data),
 */
 void show_file_chooser_for_save (const char *title,
 				 GtkWindow *parent,
+				 const char *default_folder,
 				 const char *default_filename,
 				 void (*cont) (char *uri, void *data),
 				 void *data);
@@ -441,6 +504,7 @@ void cleanup_temp_file ();
    stdout and stderr of the subprocess are redirected into the log.
 */
 void run_cmd (char **argv,
+	      bool ignore_nonexisting,
 	      void (*cont) (int status, void *data),
 	      void *data);
 
@@ -519,10 +583,22 @@ int64_t get_free_space ();
  */
 int64_t get_free_space_at_path (const char *path);
 
-/* Checks if there's some volume mounted in the specified path */
-gboolean volume_path_is_mounted (const gchar *path);
+/* Checks if there's some volume mounted in the specified path and is
+   writable.
+*/
+gboolean volume_path_is_mounted_writable (const gchar *path);
 
 /* Set a DBUS message to reboot the device */
 void send_reboot_message (void);
 
+/* Save the LAST_UPDATE timstamp from disk */
+void save_last_update_time (time_t t);
+
+/* Load the LAST_UPDATE timstamp from disk */
+int load_last_update_time ();
+
+/* Check whether the package cache is up-to-date or not */
+gboolean is_package_cache_updated ();
+
 #endif /* !UTIL_H */
+
